#
# spec file for package python-sparse
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == ""
%define psuffix %{nil}
%bcond_with test
BuildArch:      noarch
%else
%bcond_without test
%define psuffix -%{flavor}
# 32bit fails in half of the test suite because the tests try to convert to 64bit types
ExcludeArch:    %{ix86} %{arm} ppc
%endif

%{?sle15_python_module_pythons}
Name:           python-sparse%{psuffix}
Version:        0.15.5
Release:        1.3
Summary:        Sparse n-dimensional arrays for Python
License:        BSD-3-Clause
URL:            https://github.com/pydata/sparse
Source:         https://files.pythonhosted.org/packages/source/s/sparse/sparse-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 64}
BuildRequires:  %{python_module setuptools_scm >= 8}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numba >= 0.49
Requires:       python-numpy >= 1.17
Requires:       python-scipy >= 0.19
%if %{with test}
BuildRequires:  %{python_module dask-array}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module sparse = %{version}}
%endif
%python_subpackages

%description
This module implements sparse multidimensional arrays on top of NumPy and
Scipy.sparse. It generalizes the scipy.sparse.coo_matrix layout, but
extends beyond just rows and columns to an arbitrary number of
dimensions.

The original motivation is for machine learning algorithms, but it is
intended for somewhat general use.

%prep
%autosetup -p1 -n sparse-%{version}
sed -i /addopts/d pytest.ini

%build
%if !%{with test}
%pyproject_wheel
%endif

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
%pytest -n auto
%endif

%if !%{with test}
%files %{python_files}
%doc README.rst docs/*.rst
%license LICENSE
%{python_sitelib}/sparse
%{python_sitelib}/sparse-%{version}.dist-info
%endif

%changelog
* Tue Feb 25 2025 Dirk Müller <dmueller@suse.com>
- update to 0.15.5:
  * Make sure [r]matmul__ returns NotImplemented on invalid types.
* Tue Nov 26 2024 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Re-enable python 3.13 since numba has been patched to support it
* Wed Nov 20 2024 Ben Greiner <code@bnavigator.de>
- Skip python313: No numba 0.61 yet
* Mon Sep 23 2024 Ben Greiner <code@bnavigator.de>
- Switch to testing in multibuild: The obs runtime requirement
  resolver deals with numba/numpy blockage more gracefully than
  trying to resolve a BuildRequires on them. Numba 0.60 is
  restricted to Numpy < 2.1 right now.
  * Test in parallel with xdist
* Fri Aug 30 2024 Ben Greiner <code@bnavigator.de>
- Unpin numpy 2
* Mon Jul  8 2024 Steve Kowalik <steven.kowalik@suse.com>
- Limit numpy to < 2.
* Thu Jun  6 2024 Ben Greiner <code@bnavigator.de>
- Update to 0.15.4
  * no changelog since 0.15.1
- Release 0.15.1
  * Fix regression where with XArray by supporting all API
    functions via the Array API standard. (PR #622 thanks
    @hameerabbasi)
- Release 0.15.0
  * Fix regression where DeprecationWarning`s were being fired
    unexpectedly. (:pr:`581 thanks @hameerabbasi)
  * Extended sparse.einsum support (PR #579 thanks @HadrienNU)
  * General code clean-up (PR #586 thanks @MHRasmy, PR #598 thanks
    @jamestwebber)
  * Bug fixes with respect to NumPy compatibility (PR #598 thanks
    @hameerabbasi, PR #609 thanks @Illviljan, PR #620 thanks
    @mtsokol)
  * Bug fixes with respect to GCXS (PR #611 thanks @EuGig, PR #601
    thanks @jamestwebber)
  * Array API standard support (PR #612, PR #613, PR #614, PR #615,
    PR #619, PR #620 thanks @mtsokol)
  * matrepr support for display of sparse data (PR #605, PR #606
    thanks @alugowski).
  * Larger code clean-up with Ruff formatter and linter (PR #617,
    PR #621 thanks @hameerabbasi)
* Fri Mar 29 2024 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Mon May 29 2023 Ben Greiner <code@bnavigator.de>
- Unskip python311: numby 0.57 is released
- Skip test_tensordot: gh#pydata/sparse#594
* Sat Mar 25 2023 Ben Greiner <code@bnavigator.de>
- Update to 0.14.0
  * sparse.einsum support (PR #564 thanks @jcmgray)
  * Some bug-fixes (PR #524, PR #527, PR #555 thanks @hameerabbasi,
    PR #569, thanks @jamestwebber, PR #534, thanks
    @sarveshbhatnagar)
  * Some performance improvements (PR #570, thanks @jamestwebber,
    PR #540, thanks @smldub).
- Skip python311 build: no numba yet
- Drop skip-32bit-archs.patch, disable 32bit test suite: too many
  tests involve 64bit types
* Fri Oct 21 2022 Matej Cepl <mcepl@suse.com>
- Add skip-32bit-archs.patch skiping a failing test on 32bit arch
  (gh#pydata/sparse#490).
- Also remove conditional python_module definition.
* Thu Jul 14 2022 Ben Greiner <code@bnavigator.de>
- remove stray ancient pathlib requirement
- Dask supports Python 3.10 now: reenable tests
* Mon Jan 24 2022 Ben Greiner <code@bnavigator.de>
- Don't test optional dask for python310: not supported yet
* Wed Sep 22 2021 Ben Greiner <code@bnavigator.de>
- Update to 0.13.0
  * GCXS improvements and changes.
  * Maintainence fixes
  * sparse.DOK.from_scipy_sparse method
  * Black re-formatting
  * Add sparse.pad
  * Switch to GitHub Actions
  * Fix a number of bugs in format conversion.
  * Fix bug in sparse.matmul for higher-dimensional arrays.
  * Fix scalar conversion to COO
  * Fix OOB memory accesses
  * Fixes element-wise ops with scalar COO array.
  * Fix scalar broadcast_to with nnz==0.
  * Add order parameter to {zero, ones, full}[_like].
  * Fix tensordot typing bugs.
- Release 0.12.0
  * There are a number of large changes in this release. For
    example, we have implemented the GCXS type, and its
    specializations CSR and CSC. We plan on gradually improving the
    performance of these.
  * A number of GCXS fixes and additions
  * Ability to change the index dtype for better storage
    characteristics.
  * Some work on DOK arrays to bring them closer to the other
    formats
  * CSR and CSC specializations of GCXS
  * Fix a number of bugs
  * Add nnz parameter to sparse.random
- Drop sparse-pr421-fix-cootype.patch merged upstream
* Fri Feb 12 2021 Dirk Müller <dmueller@suse.com>
- skip python 3.6 build
* Mon Dec 28 2020 Benjamin Greiner <code@bnavigator.de>
- Update to 0.11.2
  * Fix TypingError on sparse.dot with complex dtypes. (Issue #403,
    PR #404)
- Changelog for 0.11.1
  * Fix ValueError on sparse.dot with extremely small values.
    (Issue #398, PR #399)
- Changelog for 0.11.0
  * Improve the performance of sparse.dot. (Issue #331, PR #389,
    thanks @daletovar)
  * Added the COO.swapaxes method. (PR #344, thanks @lueckem)
  * Added multi-axis 1-D indexing support. (PR #343, thanks
    @mikeymezher)
  * Fix outer for arrays that weren’t one-dimensional. (Issue #346,
    PR #347)
  * Add casting kwarg to COO.astype. (Issue #391, PR #392)
  * Fix for COO constructor accepting invalid inputs. (Issue #385,
    PR #386)
  - Changelog for 0.10.0
  * Fixed a bug where converting an empty DOK array to COO leads to
    an incorrect dtype. (Issue #314, PR #315)
  * Change code formatter to black. (PR #284)
  * Add COO.flatten and sparse.outer. (Issue #316, PR #317).
  * Remove broadcasting restriction between sparse arrays and dense
    arrays. (Issue #306, PR #318)
  * Implement deterministic dask tokenization. (Issue #300, PR
    [#320], thanks @danielballan)
  * Improve testing around densification (PR #321, thanks
    @danielballan)
  * Simplify Numba extension. (PR #324, thanks @eric-wieser).
  * Respect copy=False in astype (PR #328, thanks @eric-wieser).
  * Replace linear_loc with ravel_multi_index, which is 3x faster.
    (PR #330, thanks @eric-wieser).
  * Add error msg to tensordot operation when ndim==0 (Issue #332,
    PR #333, thanks @guilhermeleobas).
  * Maintainence fixes for Sphinx 3.0 and Numba 0.49, and dropping
    support for Python 3.5. (PR #337).
  * Fixed signature for numpy.clip.
- Changelog for 0.9.1
  * Fixed a bug where indexing with an empty list could lead to
    issues. (Issue #281, PR #282)
  * Change code formatter to black. (PR #284)
  * Add the diagonal and diagonalize functions. (Issue #288, PR
    [#289], thanks @pettni)
  * Add HTML repr for notebooks. (PR #283, thanks @daletovar)
  * Avoid making copy of coords when making a new COO array.
  * Add stack and concatenate for GCXS. (Issue #301, PR #303,
    thanks @daletovar).
  * Fix issue where functions dispatching to an attribute access
    wouldn’t work with __array_function__. (Issue #308, PR #309).
  * Add partial support for constructing and mirroring COO objects
    to Numba.
- add sparse-pr421-fix-cootype.patch
  * gh#pydata/sparse#420
  * gh#pydata/sparse#421
* Thu Sep  5 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.8.0
  * Fixed a bug where an array with size == 1 and nnz == 0
    could not be broadcast.
  * Add ``std`` and ``var``.
  * Move to Azure Pipelines with CI for Windows, macOS and
    Linux.
  * Add ``resize``, and change ``reshape`` so it raises a
    ``ValueError`` on shapes that don't correspond to the
    same size.
  * Add ``isposinf`` and ``isneginf``.
  * Fix ``tensordot`` when nnz = 0.
  * Modifications to ``__array_function__`` to allow for sparse
    XArrays.
  * Add not-yet-public support for GCXS.
  * Improvements to ``__array_function__``.
  * Convert all Numba lists to typed lists.
  * Why write code when it exists elsewhere?
  * Fix some element-wise operations with scalars.
  * Private modules should be private, and tests should be in the package.
* Tue Apr  9 2019 pgajdos@suse.com
- version update to 0.7.0
  * python3-only package, for other changes see changelog.rst
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Jul 29 2018 jengelh@inai.de
- Update descriptions.
* Thu May 24 2018 toddrme2178@gmail.com
- Update to 0.3.1
  * Add Elementwise broadcasting and broadcast_to (:pr:`35`) `Hameer Abbasi`_
  * Add Bitwise ops (:pr:`38`) `Hameer Abbasi`_
  * Add slicing support for Ellipsis and None (:pr:`37`) `Matthew Rocklin`_
  * Add triu and tril and tests (:pr:`40`) `Hameer Abbasi`_
  * Extend gitignore file  (:pr:`42`) `Nils Werner`_
  * Update MANIFEST.in (:pr:`45`) `Matthew Rocklin`_
  * Remove auto densification and unify operator code (:pr:`46`) `Hameer Abbasi`_
  * Fix nnz for scalars (:pr:`48`) `Hameer Abbasi`_
  * Update README (:pr:`50`) (:pr:`53`) `Hameer Abbasi`_
  * Fix large concatenations and stacks (:pr:`50`) `Hameer Abbasi`_
  * Add __array_ufunc__ for __call__ and reduce (:pr:`49`) `Hameer Abbasi`_
  * Update documentation (:pr:`54`) `Hameer Abbasi`_
  * Flake8 and coverage in pytest (:pr:`59`) `Nils Werner`_
  * Copy constructor (:pr:`55`) `Nils Werner`_
  * Add random function (:pr:`41`) `Nils Werner`_
  * Add lots of indexing features (:pr:`57`) `Hameer Abbasi`_
  * Validate .transpose axes (:pr:`61`) `Nils Werner`_
  * Simplify axes normalization logic `Nils Werner`_
  * User higher density for sparse.random in tests (:pr:`64`) `Keisuke Fujii`_
  * Support left-side np.number elemwise operations (:pr:`67`) `Keisuke Fujii`_
  * Support len on COO (:pr:`68`) `Nils Werner`_
  * Update scipy version in requirements (:pr:`70`) `Hameer Abbasi`_
  * Documentation (:pr:`43`) `Nils Werner`_ and `Hameer Abbasi`_
  * Use Tox for cross Python-version testing (:pr:`77`) `Nils Werner`_
  * Support mixed sparse-dense when result is sparse (:pr:`75`) `Hameer Abbasi`_
  * Update contributing.rst (:pr:`76`) `Hameer Abbasi`_
  * Size and density properties (:pr:`69`) `Nils Werner`_
  * Fix large sum (:pr:`83`) `Hameer Abbasi`_
  * Add DOK (:pr:`85`) `Hameer Abbasi`_
  * Implement __array__ protocol (:pr:`87`) `Matthew Rocklin`_
- spec file cleanups
* Thu Nov  2 2017 arun@gmx.de
- update to version 0.1.1:
  * Add @ operator (simplify) (#16)
  * Opt in to caching
  * Cache reshape and transpose
  * Add tocsr method and sorted checking
  * Fix windows errors around int/long
  * use elemwise_binary in __add__
  * Fix bug in large reductions
  * Add out= keywords to ufuncs
* Thu May 25 2017 toddrme2178@gmail.com
- Initial version
